

let SerialPort = require('serialport');     // include the serialport library
let	portName =  '/dev/ttyACM0';            // get the port name from the command line



// db
const db = require("./models/database");
db.mongoose
  .connect(db.url, {
    useNewUrlParser: true,
    useUnifiedTopology: true,
  })
  .then(() => {
    console.log("Connected to the database!");
  })
  .catch(err => {
    console.log("Cannot connect to the database!", err);
    process.exit();
  });

  const Sensor = db.sensor;


// if they didn't give a port name, tell them so, then quit:
if (!portName) {
  giveInstructions();
}

var myPort = new SerialPort(portName, 9600);// open the port
var Readline = SerialPort.parsers.Readline; // make instance of Readline parser
var parser = new Readline();                // make a new parser to read ASCII lines
myPort.pipe(parser);                        // pipe the serial stream to the parser

// these are the definitions for the serial events:
myPort.on('open', showPortOpen);    // called when the serial port opens
myPort.on('close', showPortClose);  // called when the serial port closes
myPort.on('error', showError);      // called when there's an error with the serial port
parser.on('data', readSerialData);  // called when there's new data incoming

// these are the functions called when the serial events occur:
function showPortOpen() {
  console.log('port open. Data rate: ' + myPort.baudRate);
}

function readSerialData(data) {
  console.log(data, new Date(Date.now()));
  if(!isNaN(data) && data>=0 && data<=100){
 
    
  const s = new Sensor({value : parseFloat(data), timestamp: Date.now()})
  s.save(function(err, doc) {
    if (err) return console.error(err);
    console.log("Document inserted succussfully! " + parseFloat(data));
  });
}
}

function showPortClose() {
  console.log('port closed.');
}

function showError(error) {
  console.log('Serial port error: ' + error);
}

function giveInstructions() {
    console.log('you did not give a port name');
    console.log('To run this properly, type \n');
    console.log('node serial-in.js portname\n');
    console.log('run the listPorts script to get a list of ports.\n');
    process.exit(0);
}


const express = require('express')
const app = express()
// view engine setup
var path = require('path');
// app.set('views', path.join(__dirname, 'views'));
// app.set('view engine', 'twig');


const sensorConroller = require('./controllers/SensorController')


app.use('/last', sensorConroller.getLastInformations);
app.use('/lastTen', sensorConroller.getLastTenInformation)
app.use('/', sensorConroller.getInformation);


app.listen(3000, () => {
  console.log('Serveur à lécoute')
})
